@@ -14,8 +14,9 @@
 #include <string.h>
 
 #include <libxml/xmlmemory.h>
-#include <libxml/tree.h>
+#include <libxml/globals.h>
 #include <libxml/xmlerror.h>
+#include <libxml/tree.h>
 #include <libxml/xpathInternals.h>
 #include <libxml/parserInternals.h>
 #include "xslt.h"
@@ -216,6 +217,9 @@ xsltAttrTemplateValueProcess(xsltTransformContextPtr ctxt, const xmlChar *str) {
     xmlChar *expr, *val;
 
     if (str == NULL) return(NULL);
+    if (*str == 0)
+	return(xmlStrndup((xmlChar *)"", 0));
+
     cur = str;
     while (*cur != 0) {
 	if (*cur == '{') {
